#ifndef _MECH_LUT_H_
#define _MECH_LUT_H_

#include <stdio.h>

/* constants */
#define NUMPARAMS 5
#define NMECHVARS 4

/** upper bound for ascii LUT header length, in chars. */
#define MAX_HEADER_LEN 2000
/** string that ends ascii LUT header. NB: include newline if present  */
#define HEADER_END_DELIM "DATA:\n"

enum logbool {
  LINEAR = 0,
  LOGSCALE = 1
};


/*********************/
/* structures	     */
/*********************/

/**
 * Lookup table for values of a parameter. Maps bin numbers to values.
 */
struct param {
  char *name;
  double *val;			/* lookup array */
  int N;			/* bins in array */
  double min;
  double max;
  double step;
  int logscale;		       /* boolean: is the step logarithmic? */
  char *units;
};

/******************************/
/* function prototypes	      */
/******************************/

void read_param_header(FILE *infile, struct param *params[]);
struct param *init_param(char *name, int N, double min, double step, enum logbool scale, char *units);
void fill_log_param(struct param *l, int N, double min, double step);
void print_param(FILE *outfile, struct param *l);
float * const read_lut_array(FILE *infile,  struct param *params[],
			     int numparams, int numvars);
double nearest_param_index(struct param *p, float target, size_t *idx);
float * const mech_lookup_nearest(float paramvals[]);
void init_mech_lut(char *infilename);
void * const mmap_ro(int fd, size_t length);
char * remove_header(const char *arr);

#endif /* ndef _MECH_LUT_H_ */
